/**************************************************************************
 *
 * FILE  gcrimage.h
 * Copyright (c) 2007 Daniel Kahlin
 * Written by Daniel Kahlin <daniel@kahlin.net>
 * $Id: gcrimage.h,v 1.1 2007-03-31 08:34:50 tlr Exp $
 *
 * DESCRIPTION
 *   This program scans a g64 file and presents the results to the screen.
 *
 ******/
#ifndef GCRIMAGE_H
#define GCRIMAGE_H

#define MAX_TRACKS 128
#define MAX_SECTORS 32

#define TYPE_G64 1
#define TYPE_NIB 2
#define TYPE_NB2 3

struct Header {
    /* header info */
    int type;
    uint8_t num_tracks;
    uint16_t track_size;
    uint32_t track_offs[MAX_TRACKS];
    uint32_t speed_offs[MAX_TRACKS];
    /* calculated info */
    int track_max;
    int num_halftracks;
    int num_speedblocks;
};

#define MAX_TRACKLEN 16384
#define MAX_SYNCS 256
#define MAX_DECODELEN 16384

struct Track {
    int track;

    /* track data */
    uint8_t trackbuf[MAX_TRACKLEN];
    int speedbuf[MAX_TRACKLEN];
    int track_len;

    /* calculated data */
    int track_len_bits;
    int num_syncs;
    int sync_start[MAX_SYNCS];
    int sync_end[MAX_SYNCS];
};

struct Image {
    FILE *fp;
    struct Header head;
};

extern int sync_threshold_g;

struct Image *open_image(const char *name);
void close_image(struct Image *img);
struct Track *read_track(struct Image *img, int track);
int scan_sector(struct Track *trk, int sector, uint8_t *id);
int read_sector(struct Track *trk, int sector, uint8_t *buf, uint8_t *id);

int gcr_decode_block(struct Track *trk, int sb, int eb, int *dest);
uint8_t get_bit(struct Track *trk, int bit);
uint8_t get_byte(struct Track *trk, int bit);
uint16_t get_10bit(struct Track *trk, int bit);
int gcr_decode(uint16_t d);

#endif /* GCRIMAGE_H */
/* eof */
